﻿using System;
using System.Runtime.Serialization;
using Kreta.Framework.Localization;
using Kreta.Framework.Logging;

namespace Kreta.Framework
{
    /// <summary>
    /// Érvénytelen konfiguráció.
    /// </summary>
    [FriendlyName(1000023, "Érvénytelen konfiguráció.")]
    [ErrorCode(Events.FRAMEWORK_CONFIG_INVALIDCONFIG)]
    [Serializable]
    public sealed class InvalidConfigurationException : ServerException
    {
        const string _errorMessage = "Invalid configuration.";

        /// <summary>
        /// Az osztály alapértelmezett konstruktora.
        /// </summary>
        public InvalidConfigurationException()
            : this(_errorMessage, null) { }

        /// <summary>
        /// Az osztály konstruktora.
        /// </summary>
        /// <param name="message">A kivétel üzenete</param>
        public InvalidConfigurationException(string message)
            : this(message, null) { }

        /// <summary>
        /// Az osztály alapértelmezett konstruktora.
        /// </summary>
        /// <param name="innerException">A belső kivétel</param>
        public InvalidConfigurationException(Exception innerException)
            : this(_errorMessage, innerException) { }

        /// <summary>
        /// Az osztály konstruktora.
        /// </summary>
        /// <param name="message">A kivétel üzenete</param>
        /// <param name="innerException">A belső kivétel</param>
        public InvalidConfigurationException(string message, Exception innerException)
            : base(message, innerException, true) { }

        /// <summary>
        /// Az osztály konstruktora.
        /// </summary>
        /// <param name="info">Sorosítási adatok</param>
        /// <param name="context">Sorosítási adatfolyam</param>
        InvalidConfigurationException(SerializationInfo info, StreamingContext context)
                : base(info, context) { }
    }
}
