﻿using System;
using System.Runtime.Serialization;
using Kreta.Framework.Localization;
using Kreta.Framework.Logging;

namespace Kreta.Framework
{
    /// <summary>
    /// Munkamenet-hibákkal kapcsolatos okok
    /// </summary>
    public enum SessionReason
    {
        /// <summary>
        /// A munkamenet nem létezik
        /// </summary>
        NOT_EXISTS,

        /// <summary>
        /// A munkamenet már létezik
        /// </summary>
        EXISTS
    }

    /// <summary>
    /// Érvénytelen munkamenet azonosító.
    /// </summary>
    [FriendlyName(1000043, "Érvénytelen vagy lejárt munkamenet.")]
    [ErrorCode(Events.FRAMEWORK_SESSION_INVALID)]
    [Serializable]
    public sealed class InvalidSessionException : FrameworkException
    {
        /// <summary>
        /// Az osztály konstruktora.
        /// </summary>
        /// <param name="sessionid">A munkamenet azonosítója</param>
        /// <param name="reason">A kivétel oka</param>
        public InvalidSessionException(string sessionid, SessionReason reason)
            : base("Érvénytelen vagy lejárt munkamenet.", null)
        {
            Data.Add(LogParameter.REASON, reason);
            Data.Add(LogParameter.SESSIONID, sessionid);
        }

        /// <summary>
        /// Az osztály konstruktora.
        /// </summary>
        /// <param name="info">Sorosítási adatok</param>
        /// <param name="context">Sorosítási adatfolyam</param>
        InvalidSessionException(SerializationInfo info, StreamingContext context)
            : base(info, context) { }
    }
}
